diff --git a/documentation/extensions/dataforms.html b/documentation/extensions/dataforms.html
index 1c2aee457..cfc5b1f78 100644
--- a/documentation/extensions/dataforms.html
+++ b/documentation/extensions/dataforms.html
@@ -15,7 +15,7 @@ tasks such as registration and searching using Forms.
diff --git a/documentation/extensions/intro.html b/documentation/extensions/intro.html
index 811ba9174..244edb334 100644
--- a/documentation/extensions/intro.html
+++ b/documentation/extensions/intro.html
@@ -32,17 +32,17 @@
diff --git a/documentation/extensions/invitation.html b/documentation/extensions/invitation.html
index c15b15824..6fbbf892c 100644
--- a/documentation/extensions/invitation.html
+++ b/documentation/extensions/invitation.html
@@ -17,8 +17,8 @@ users to a group chat room.
-JEP related: N/A -- this protocol is outdated now that the Multi-User Chat (MUC) JEP is available
-(JEP-45). However, most
+XEP related: N/A -- this protocol is outdated now that the Multi-User Chat (MUC) XEP is available
+(XEP-45). However, most
existing clients still use this older protocol. Once MUC support becomes more
widespread, this API may be deprecated.
diff --git a/documentation/extensions/messageevents.html b/documentation/extensions/messageevents.html
index d91492b3f..163a800a2 100644
--- a/documentation/extensions/messageevents.html
+++ b/documentation/extensions/messageevents.html
@@ -19,7 +19,7 @@ display, and composition of messages. There are three stages in this extension:<
Reacting to Event Notification Requests
Reacting to Event Notifications
-JEP related: JEP-22
+XEP related: XEP-22
Description
diff --git a/documentation/extensions/muc.html b/documentation/extensions/muc.html
index f4e4877c8..54ce72fb0 100644
--- a/documentation/extensions/muc.html
+++ b/documentation/extensions/muc.html
@@ -22,7 +22,7 @@ Allows configuration of, participation in, and administration of individual text
Manage role modifications
Manage affiliation modifications
-JEP related: JEP-45
+XEP related: XEP-45
diff --git a/documentation/extensions/privatedata.html b/documentation/extensions/privatedata.html
index 4d0f65887..c90dff29f 100644
--- a/documentation/extensions/privatedata.html
+++ b/documentation/extensions/privatedata.html
@@ -19,7 +19,7 @@ XML namespace. Example private data:
</color>
-JEP related: JEP-49
+XEP related: XEP-49
diff --git a/documentation/extensions/rosterexchange.html b/documentation/extensions/rosterexchange.html
index e014da111..1bb8d7fc0 100644
--- a/documentation/extensions/rosterexchange.html
+++ b/documentation/extensions/rosterexchange.html
@@ -17,7 +17,7 @@ are received from other XMPP clients.
Send a roster's entry
Receive roster entries
-JEP related: JEP-93
+XEP related: XEP-93
diff --git a/documentation/extensions/time.html b/documentation/extensions/time.html
index 7c00efa77..800a26169 100644
--- a/documentation/extensions/time.html
+++ b/documentation/extensions/time.html
@@ -11,7 +11,7 @@
Supports a protocol that XMPP clients use to exchange their respective local
times and time zones.
-JEP related: JEP-90
+XEP related: XEP-90
diff --git a/documentation/extensions/xhtml.html b/documentation/extensions/xhtml.html
index f283f57ba..8cdee0d8d 100644
--- a/documentation/extensions/xhtml.html
+++ b/documentation/extensions/xhtml.html
@@ -18,7 +18,7 @@ XHTML messages:
Receive an XHTML Message
Discover support for XHTML Messages
-JEP related: JEP-71
+XEP related: XEP-71
diff --git a/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/CompressionTest.java b/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/CompressionTest.java
index 4b770ccc8..7e01e5f27 100644
--- a/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/CompressionTest.java
+++ b/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/CompressionTest.java
@@ -24,7 +24,7 @@ import org.jivesoftware.smack.test.SmackTestCase;
import org.jivesoftware.smackx.packet.Version;
/**
- * Ensure that stream compression (JEP-138) is correctly supported by Smack.
+ * Ensure that stream compression (XEP-138) is correctly supported by Smack.
*
* @author Gaston Dombiak
*/
diff --git a/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/MultipleRecipientManagerTest.java b/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/MultipleRecipientManagerTest.java
index 084869d82..62391edaa 100644
--- a/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/MultipleRecipientManagerTest.java
+++ b/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/MultipleRecipientManagerTest.java
@@ -30,7 +30,7 @@ import java.util.Arrays;
import java.util.List;
/**
- * Tests that JEP-33 support in Smack is correct.
+ * Tests that XEP-33 support in Smack is correct.
*
* @author Gaston Dombiak
*/
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/address/MultipleRecipientManager.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/address/MultipleRecipientManager.java
index d7819927f..3fe189fee 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/address/MultipleRecipientManager.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/address/MultipleRecipientManager.java
@@ -40,7 +40,7 @@ import java.util.logging.Logger;
/**
* A MultipleRecipientManager allows to send packets to multiple recipients by making use of
- * JEP-33: Extended Stanza Addressing.
+ * XEP-33: Extended Stanza Addressing.
* It also allows to send replies to packets that were sent to multiple recipients.
*
* @author Gaston Dombiak
@@ -57,9 +57,9 @@ public class MultipleRecipientManager {
/**
* Sends the specified packet to the list of specified recipients using the
- * specified connection. If the server has support for JEP-33 then only one
+ * specified connection. If the server has support for XEP-33 then only one
* packet is going to be sent to the server with the multiple recipient instructions.
- * However, if JEP-33 is not supported by the server then the client is going to send
+ * However, if XEP-33 is not supported by the server then the client is going to send
* the packet to each recipient.
*
* @param connection the connection to use to send the packet.
@@ -72,8 +72,8 @@ public class MultipleRecipientManager {
* list exists.
* @throws FeatureNotSupportedException if special XEP-33 features where requested, but the
* server does not support them.
- * @throws XMPPErrorException if server does not support JEP-33: Extended Stanza Addressing and
- * some JEP-33 specific features were requested.
+ * @throws XMPPErrorException if server does not support XEP-33: Extended Stanza Addressing and
+ * some XEP-33 specific features were requested.
* @throws NoResponseException if there was no response from the server.
* @throws NotConnectedException
*/
@@ -84,8 +84,8 @@ public class MultipleRecipientManager {
/**
* Sends the specified packet to the list of specified recipients using the specified
- * connection. If the server has support for JEP-33 then only one packet is going to be sent to
- * the server with the multiple recipient instructions. However, if JEP-33 is not supported by
+ * connection. If the server has support for XEP-33 then only one packet is going to be sent to
+ * the server with the multiple recipient instructions. However, if XEP-33 is not supported by
* the server then the client is going to send the packet to each recipient.
*
* @param connection the connection to use to send the packet.
@@ -99,8 +99,8 @@ public class MultipleRecipientManager {
* @param replyRoom JID of a MUC room to which responses should be sent or null
* indicating that they can reply to any address.
* @param noReply true means that receivers should not reply to the message.
- * @throws XMPPErrorException if server does not support JEP-33: Extended Stanza Addressing and
- * some JEP-33 specific features were requested.
+ * @throws XMPPErrorException if server does not support XEP-33: Extended Stanza Addressing and
+ * some XEP-33 specific features were requested.
* @throws NoResponseException if there was no response from the server.
* @throws FeatureNotSupportedException if special XEP-33 features where requested, but the
* server does not support them.
@@ -115,10 +115,10 @@ public class MultipleRecipientManager {
serviceAddress);
}
else {
- // Server does not support JEP-33 so try to send the packet to each recipient
+ // Server does not support XEP-33 so try to send the packet to each recipient
if (noReply || (replyTo != null && replyTo.trim().length() > 0) ||
(replyRoom != null && replyRoom.trim().length() > 0)) {
- // Some specified JEP-33 features were requested so throw an exception alerting
+ // Some specified XEP-33 features were requested so throw an exception alerting
// the user that this features are not available
throw new FeatureNotSupportedException("Extended Stanza Addressing");
}
@@ -191,7 +191,7 @@ public class MultipleRecipientManager {
serviceAddress);
}
else {
- // Server does not support JEP-33 so try to send the packet to each recipient
+ // Server does not support XEP-33 so try to send the packet to each recipient
sendToIndividualRecipients(connection, reply, to, cc, null);
}
}
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkManager.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkManager.java
index 597b32ebf..4c3303503 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkManager.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkManager.java
@@ -34,10 +34,10 @@ import org.jivesoftware.smackx.iqprivate.PrivateDataManager;
/**
- * Provides methods to manage bookmarks in accordance with JEP-0048. Methods for managing URLs and
+ * Provides methods to manage bookmarks in accordance with XEP-0048. Methods for managing URLs and
* Conferences are provided.
*
- * It should be noted that some extensions have been made to the JEP. There is an attribute on URLs
+ * It should be noted that some extensions have been made to the XEP. There is an attribute on URLs
* that marks a url as a news feed and also a sub-element can be added to either a URL or conference
* indicated that it is shared amongst all users on a server.
*
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkedConference.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkedConference.java
index 68e335b2e..0bbb1395e 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkedConference.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkedConference.java
@@ -18,7 +18,7 @@
package org.jivesoftware.smackx.bookmarks;
/**
- * Respresents a Conference Room bookmarked on the server using JEP-0048 Bookmark Storage JEP.
+ * Respresents a Conference Room bookmarked on the server using XEP-0048 Bookmark Storage XEP.
*
* @author Derek DeMoro
*/
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkedURL.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkedURL.java
index 70e9d67fc..d00161add 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkedURL.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/BookmarkedURL.java
@@ -18,7 +18,7 @@
package org.jivesoftware.smackx.bookmarks;
/**
- * Respresents one instance of a URL defined using JEP-0048 Bookmark Storage JEP.
+ * Respresents one instance of a URL defined using XEP-0048 Bookmark Storage XEP.
*
* @author Derek DeMoro
*/
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/Bookmarks.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/Bookmarks.java
index f70de8a99..8d9d866fc 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/Bookmarks.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/bookmarks/Bookmarks.java
@@ -27,7 +27,7 @@ import java.util.List;
/**
* Bookmarks is used for storing and retrieving URLS and Conference rooms.
- * Bookmark Storage (JEP-0048) defined a protocol for the storage of bookmarks to conference rooms and other entities
+ * Bookmark Storage (XEP-0048) defined a protocol for the storage of bookmarks to conference rooms and other entities
* in a Jabber user's account.
* See the following code sample for saving Bookmarks:
*
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/filetransfer/FileTransferNegotiator.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/filetransfer/FileTransferNegotiator.java
index 6b1c4cc16..0f59deec9 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/filetransfer/FileTransferNegotiator.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/filetransfer/FileTransferNegotiator.java
@@ -43,7 +43,7 @@ import org.jivesoftware.smackx.xdata.FormField;
import org.jivesoftware.smackx.xdata.packet.DataForm;
/**
- * Manages the negotiation of file transfers according to JEP-0096. If a file is
+ * Manages the negotiation of file transfers according to XEP-0096. If a file is
* being sent the remote user chooses the type of stream under which the file
* will be sent.
*
@@ -357,13 +357,13 @@ public class FileTransferNegotiator {
* If they accept, the packet will contain the other user's chosen stream
* type to send the file across. The two choices this implementation
* provides to the other user for file transfer are SOCKS5 Bytestreams,
+ * href="http://www.xmpp.org/extensions/jep-0065.html">SOCKS5 Bytestreams,
* which is the preferred method of transfer, and In-Band Bytestreams,
+ * href="http://www.xmpp.org/extensions/jep-0047.html">In-Band Bytestreams,
* which is the fallback mechanism.
*
* The other user may choose to decline the file request if they do not
- * desire the file, their client does not support JEP-0096, or if there are
+ * desire the file, their client does not support XEP-0096, or if there are
* no acceptable means to transfer the file.
*
* Finally, if the other user does not respond this method will return null
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/filetransfer/StreamNegotiator.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/filetransfer/StreamNegotiator.java
index a8b873a13..a46ec4166 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/filetransfer/StreamNegotiator.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/filetransfer/StreamNegotiator.java
@@ -37,7 +37,7 @@ import java.io.OutputStream;
/**
* After the file transfer negotiation process is completed according to
- * JEP-0096, the negotiation process is passed off to a particular stream
+ * XEP-0096, the negotiation process is passed off to a particular stream
* negotiator. The stream negotiator will then negotiate the chosen stream and
* return the stream to transfer the file.
*
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/iqprivate/PrivateDataManager.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/iqprivate/PrivateDataManager.java
index 120bdd3d5..70141eef2 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/iqprivate/PrivateDataManager.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/iqprivate/PrivateDataManager.java
@@ -50,7 +50,7 @@ import java.util.WeakHashMap;
* a {@link DefaultPrivateData} instance will be returned.
*
* Warning: this is an non-standard protocol documented by
- * JEP-49. Because this is a
+ * XEP-49. Because this is a
* non-standard protocol, it is subject to change.
*
* @author Matt Tucker
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/muc/packet/GroupChatInvitation.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/muc/packet/GroupChatInvitation.java
index f7d807d8d..2b8422f29 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/muc/packet/GroupChatInvitation.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/muc/packet/GroupChatInvitation.java
@@ -43,8 +43,8 @@ import org.xmlpull.v1.XmlPullParser;
* // Create a packet collector or packet listeners using the filter...
*
*
- * Note: this protocol is outdated now that the Multi-User Chat (MUC) JEP is available
- * (JEP-45). However, most
+ * Note: this protocol is outdated now that the Multi-User Chat (MUC) XEP is available
+ * (XEP-45). However, most
* existing clients still use this older protocol. Once MUC support becomes more
* widespread, this API may be deprecated.
*
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/muc/packet/MUCUser.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/muc/packet/MUCUser.java
index 51460c018..00e91bc79 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/muc/packet/MUCUser.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/muc/packet/MUCUser.java
@@ -520,7 +520,7 @@ public class MUCUser implements PacketExtension {
/**
* Status code assists in presenting notification messages. The following link provides the
- * list of existing error codes (@link http://www.jabber.org/jeps/jep-0045.html#errorstatus).
+ * list of existing error codes (@link http://www.xmpp.org/extensions/jep-0045.html#errorstatus).
*
* @author Gaston Dombiak
*/
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/search/SimpleUserSearch.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/search/SimpleUserSearch.java
index 675bac4f2..e38481af0 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/search/SimpleUserSearch.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/search/SimpleUserSearch.java
@@ -25,7 +25,7 @@ import java.util.ArrayList;
import java.util.List;
/**
- * SimpleUserSearch is used to support the non-dataform type of JEP 55. This provides
+ * SimpleUserSearch is used to support the non-dataform type of XEP 55. This provides
* the mechanism for allowing always type ReportedData to be returned by any search result,
* regardless of the form of the data returned from the server.
*
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/search/UserSearchManager.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/search/UserSearchManager.java
index df552b584..170e9408a 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/search/UserSearchManager.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/search/UserSearchManager.java
@@ -31,7 +31,7 @@ import java.util.Collection;
import java.util.List;
/**
- * The UserSearchManager is a facade built upon Jabber Search Services (JEP-055) to allow for searching
+ * The UserSearchManager is a facade built upon Jabber Search Services (XEP-055) to allow for searching
* repositories on a Jabber Server. This implementation allows for transparency of implementation of
* searching (DataForms or No DataForms), but allows the user to simply use the DataForm model for both
* types of support.
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/vcardtemp/packet/VCard.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/vcardtemp/packet/VCard.java
index 0a368fb38..37c5b9882 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/vcardtemp/packet/VCard.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/vcardtemp/packet/VCard.java
@@ -45,7 +45,7 @@ import org.jivesoftware.smackx.vcardtemp.VCardManager;
* SMACK jabber library.
*
* You should refer to the
- * JEP-54 documentation.
+ * XEP-54 documentation.
*
* Please note that this class is incomplete but it does provide the most commonly found
* information in vCards. Also remember that VCard transfer is not a standard, and the protocol
@@ -114,7 +114,7 @@ public class VCard extends IQ {
private String photoBinval;
/**
- * Such as DESC ROLE GEO etc.. see JEP-0054
+ * Such as DESC ROLE GEO etc.. see XEP-0054
*/
private Map otherSimpleFields = new HashMap();
diff --git a/smack-extensions/src/main/java/org/jivesoftware/smackx/xhtmlim/packet/XHTMLExtension.java b/smack-extensions/src/main/java/org/jivesoftware/smackx/xhtmlim/packet/XHTMLExtension.java
index 30903dfda..996073818 100644
--- a/smack-extensions/src/main/java/org/jivesoftware/smackx/xhtmlim/packet/XHTMLExtension.java
+++ b/smack-extensions/src/main/java/org/jivesoftware/smackx/xhtmlim/packet/XHTMLExtension.java
@@ -28,10 +28,10 @@ import java.util.List;
* extension is only a subset of XHTML 1.0.
*
* The following link summarizes the requirements of XHTML IM:
- * Valid tags.
+ * Valid tags.
*
* Warning: this is an non-standard protocol documented by
- * JEP-71. Because this is a
+ * XEP-71. Because this is a
* non-standard protocol, it is subject to change.
*
* @author Gaston Dombiak
diff --git a/smack-extensions/src/main/resources/org.jivesoftware.smackx/extensions.providers b/smack-extensions/src/main/resources/org.jivesoftware.smackx/extensions.providers
index 5388ede2c..ccb02cd13 100644
--- a/smack-extensions/src/main/resources/org.jivesoftware.smackx/extensions.providers
+++ b/smack-extensions/src/main/resources/org.jivesoftware.smackx/extensions.providers
@@ -172,7 +172,7 @@
org.jivesoftware.smackx.sharedgroups.packet.SharedGroupsInfo$Provider
-
+
addresses
http://jabber.org/protocol/address
diff --git a/smack-jingle/src/main/java/org/jivesoftware/smackx/jingle/packet/Jingle.java b/smack-jingle/src/main/java/org/jivesoftware/smackx/jingle/packet/Jingle.java
index 2869ed955..8ede2faaf 100644
--- a/smack-jingle/src/main/java/org/jivesoftware/smackx/jingle/packet/Jingle.java
+++ b/smack-jingle/src/main/java/org/jivesoftware/smackx/jingle/packet/Jingle.java
@@ -29,10 +29,10 @@ import java.util.List;
* An Jingle sub-packet, which is used by XMPP clients to exchange info like
* descriptions and transports. The following link summarizes the
* requirements of Jingle IM: Valid tags.
+ * href="http://www.xmpp.org/extensions/jep-0166.html">Valid tags.
*
* Warning: this is an non-standard protocol documented by JEP-166. Because this is
+ * href="http://www.xmpp.org/extensions/jep-0166.html">XEP-166. Because this is
* a non-standard protocol, it is subject to change.
*
* @author Alvaro Saurin
diff --git a/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/OfflineMessageManagerTest.java b/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/OfflineMessageManagerTest.java
index 40f6615d7..04a01e3c1 100644
--- a/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/OfflineMessageManagerTest.java
+++ b/smack-extensions/src/integration-test/java/org/jivesoftware/smackx/OfflineMessageManagerTest.java
@@ -32,7 +32,7 @@ import java.util.List;
/**
* Tests handling of offline messaging using OfflineMessageManager. This server requires the
* server to support JEP-0013: Flexible Offline Message Retrieval.
*
* @author Gaston Dombiak
*/
@@ -44,7 +44,7 @@ public class OfflineMessageManagerTest extends SmackTestCase {
public void testDiscoverFlexibleRetrievalSupport() throws XMPPException {
OfflineMessageManager offlineManager = new OfflineMessageManager(getConnection(1));
- assertTrue("Server does not support JEP-13", offlineManager.supportsFlexibleRetrieval());
+ assertTrue("Server does not support XEP-13", offlineManager.supportsFlexibleRetrieval());
}
/**
@@ -32,7 +32,7 @@ import java.util.List;
/**
* Tests handling of offline messaging using OfflineMessageManager. This server requires the
- * server to support JEP-0013: Flexible Offline Message Retrieval.
+ * server to support XEP-0013: Flexible Offline Message Retrieval.
*
* @author Gaston Dombiak